#
# spec file for package python-webcolors
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-webcolors
Version:        1.13
Release:        150400.10.3.9
Summary:        Support for color names and value formats defined by the HTML
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/ubernostrum/webcolors
Source:         https://files.pythonhosted.org/packages/source/w/webcolors/webcolors-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# test requirements
BuildRequires:  %{python_module pytest}
BuildArch:      noarch
%python_subpackages

%description
Webcolors is a simple Python module for working with HTML/CSS
color definitions.

Support is included for normalizing and converting between the
following formats (RGB colorspace only; conversion to/from HSL can be
handled by the ``colorsys`` module in the Python standard library):

* Specification-defined color names
* Six-digit hexadecimal
* Three-digit hexadecimal
* Integer ``rgb()`` triplet
* Percentage ``rgb()`` triplet

Implementations are also provided for the HTML5 color parsing and
serialization algorithms.

Full documentation is `available online <http://webcolors.readthedocs.org/>`_.

%prep
%setup -q -n webcolors-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test only the standard testsuite (python3 setup.py test launched two extra tests, one of them was unable to access the internet)
%pytest tests

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/*

%changelog
* Wed May  3 2023 dmueller@suse.com
- update to 1.13:
  * Supported Python versions are now 3.7, 3.8, 3.9, 3.10, and
    3.11.  The codebase was significantly reorganized and modernized.
    Public API is unchanged. Imports should continue to be directly
    from the top-level ``webcolors`` module; attempting to import
    from submodules is not supported.
  * Now packaging declaratively via ``pyproject.toml`` with `PEP
    517
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Sat Oct  1 2022 dmueller@suse.com
- update to 1.12:
  * CI only fixes, no bug fixes or new features
* Mon Feb  8 2021 adrian.glaubitz@suse.com
- Include in SLE-15 (bsc#1176785, jsc#ECO-3105, jsc#PM-2352)
* Mon Mar  9 2020 dmueller@suse.com
- update to 1.11.1:
  * Python 2 has reached the end of its support cycle from the Python
    core team; accordingly, Python 2 support is dropped. Supported
    Python versions are now 3.5, 3.6, 3.7, and 3.8.
* Mon Sep 16 2019 tchvatal@suse.com
- Update to 1.10:
  * Similar to the change in version 1.9 which normalized conversions to named
    colors
* Fri Jun 14 2019 mcalabkova@suse.com
- update to 1.9.1
  * When asked to provide a color name, using the CSS3/SVG set of names, for
    the hexadecimal value #808080, the integer triplet rgb(128, 128, 128), or
    the percentage triplet rgb(50%%, 50%%, 50%%), webcolors now always returns
    u'gray', never u'grey'.
  * Added a set of constants to use when referring to specifications that
    define color names <spec-constants>.
* Fri Mar 29 2019 pgajdos@suse.com
- version update to 1.8.1
  * Introduce namedtuples to represent tuple data types.
  * Get the definition-parsing test working on Python 3.
  * Documentation updates.
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Wed Apr 19 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Sun Nov 13 2016 termim@gmail.com
- Update to 1.5
* Thu Nov  5 2015 avvissu@yandex.ru
- Initial package
